@@ -50,7 +50,7 @@ class Filter(ABC):
         self._poles = np.atleast_1d(p)
         self._gain = k
         if len(self._zeros) > 2 or len(self._poles) > 2:
-            raise Exception("Filters of higher than second order are not supported.")
+            raise ValueError("Filters of higher than second order are not supported.")
 
     @abstractmethod
     def calculate(self):
@@ -165,17 +165,6 @@ class Filter(ABC):
     def _relative_degree(self):
         return len(self._poles) - len(self._zeros)
 
-    def _repr_pretty_(self, p, cycle):  # pylint: disable=unused-argument
-        p.text(
-            tabulate(
-                [
-                    ["zeros", "poles", "gain"],
-                    [self.description, self.zeros, self.poles, self.gain],
-                ],
-                headers="firstrow",
-            )
-        )
-
 
 class Integrator(Filter):
     """
@@ -395,12 +384,10 @@ class ServoDesign:
                 return i
         return None
 
-    def _add_filter_on_index(self, filter, index):  # pylint: disable=redefined-builtin
-        if index is None:
-            raise IndexError("Please provide a valid index.")
+    def _add_filter_on_index(self, filter_, index):  # pylint: disable=redefined-builtin
         if index >= self.MAX_FILTERS:
             raise IndexError("Max {0} filters are allowed.".format(self.MAX_FILTERS))
-        self._filters[index] = filter
+        self._filters[index] = filter_
 
     def add(
         self, filter, index=None, override=False
@@ -711,19 +698,13 @@ class ServoDesign:
         return plt
 
     def discrete_form(
-        self,
-        sampling_frequency=SAMPLING_RATE,  # pylint: disable=invalid-name
-        filename=None,
-        fs=None,
+        self, sampling_frequency=SAMPLING_RATE, fs=None,  # pylint: disable=invalid-name
     ):
         """
         Convert the servo and its filters to a digital,
         discrete-time representation in terms of second-order sections
         at a sampling frequency of `sampling_frequency`.
 
-        If `filename` is given, write the filter coefficients in
-        machine-readable format into this file.
-
         Returns
         -------
         :obj:`list`
@@ -752,19 +733,8 @@ class ServoDesign:
             "filters": filters,
         }
 
-        if filename:
-            with open(filename, "w") as fp:
-                fp.write(f"Sampling rate: {data['sampling_frequency']}\n")
-                fp.write(f"Gain: {data['gain']}\n")
-                fp.write(f"Filters:\n")
-                for f in data["filters"]:
-                    fp.write(f"{f}\n")
-
         return data
 
-    def _repr_pretty_(self, p, cycle):  # pylint: disable=unused-argument
-        p.text(str(self))
-
     def __str__(self):
         data = []
         for f in self._filters:
